﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Bible.Data.Web.Html;
using Bible.Data.Web.Css;
using NUnit.Framework;

namespace Bible.Data.UnitTests
{
    [TestFixture]
    public class Sandbox
    {
        [Test]
        public void Test()
        {
            string expected = "<!DOCTYPE html>\n" +
                "<html>\n" +
                "<head>\n" +
                "<title></title>\n" +
                "<meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0\" />\n" +
                "<style>\n" +
                "body {\n" +
                "background: #000000;\n" +
                "color: #FFFFFF;\n" +
                "}\n" +
                "</style>\n" +
                "</head>\n" +
                "<body>\n" +
                "<h1>God is Awesome!</h1>\n" +
                "</body>\n" +
                "</html>\n";

            HtmlDocument doc = new HtmlDocument();

            var style = new HtmlStyleElement(
                new CssGroup("body",
                    new CssSetter("background", Resource("PhoneBackgroundColor")),
                    new CssSetter("color", Resource("PhoneForegroundColor")))
                );

            var meta = new HtmlMetaElement("viewport",
                "width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0");

            var title = new HtmlTitleElement();

            doc.Head.Descendants.Add(title);
            doc.Head.Descendants.Add(meta);
            doc.Head.Descendants.Add(style);
            doc.Body.Descendants.Add(new HtmlH1Element("God is Awesome!"));

            Assert.That(doc.ToString(), Is.EqualTo(expected));
        }

        public string Resource(string name)
        {
            if (name == "PhoneBackgroundColor")
            {
                return "#000000";
            }
            else if (name == "PhoneForegroundColor")
            {
                return "#FFFFFF";
            }
            return "";
        }
    }
}
