﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using Bible.Data.Web.Html;
using Bible.Data.Web.Css;

namespace Bible.Data.UnitTests.Web_Tests.Html_Tests.HtmlHeadElement_Tests
{
    [TestFixture]
    public abstract class When_adding_an_element_to_HtmlHeadElement
    {
        protected HtmlHeadElement headElement;

        [TestFixtureSetUp]
        public virtual void SetUp()
        {
            headElement = new HtmlHeadElement();
        }
    }

    [TestFixture]
    public class When_adding_a_HtmlStyleElement_to_HtmlHeadElement
        : When_adding_an_element_to_HtmlHeadElement
    {
        [TestFixtureSetUp]
        public override void SetUp()
        {
            base.SetUp();
            HtmlStyleElement styleElement =
                new HtmlStyleElement(new CssGroup("body", new CssSetter("background", "#000000")));
            headElement.Descendants.Add(styleElement);
        }

        [Test]
        public void It_should_return_correct_Count()
        {
            Assert.That(headElement.Descendants.Count, Is.EqualTo(1));
        }

        [Test]
        public void It_should_return_correct_string_with_ToString()
        {
            string expected = "<head>\n" +
                "<style>\n" +
                "body {\n" +
                "background: #000000;\n" +
                "}\n" +
                "</style>\n" +
                "</head>\n";

            Assert.That(headElement.ToString(), Is.EqualTo(expected));
        }
    }

    [TestFixture]
    public class When_adding_a_HtmlMetaElement_to_HtmlHeadElement
        : When_adding_an_element_to_HtmlHeadElement
    {
        [TestFixtureSetUp]
        public override void SetUp()
        {
            base.SetUp();
            HtmlMetaElement metaElement =
                new HtmlMetaElement("viewport", "width=device-width");
            headElement.Descendants.Add(metaElement);
        }

        [Test]
        public void It_should_return_correct_Count()
        {
            Assert.That(headElement.Descendants.Count, Is.EqualTo(1));
        }

        [Test]
        public void It_should_return_correct_string_with_ToString()
        {
            string expected = "<head>\n" +
                "<meta name=\"viewport\" content=\"width=device-width\" />\n" +
                "</head>\n";

            Assert.That(headElement.ToString(), Is.EqualTo(expected));
        }
    }
}
