﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.IO.IsolatedStorage;
using Bible.UI.Helpers;
using System.Windows.Resources;
using System.IO;

namespace Microsoft.Phone.Controls
{
    /// <summary>
    /// Contains extension methods for the WebBrowser control.
    /// </summary>
    public static class WebBrowserExtensions
    {
        private static void SaveFileToIsoStore(String fileName)
        {
            //These files must match what is included in the application package,
            //or BinaryStream.Dispose below will throw and exception.
            using (IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (!isoStore.FileExists(fileName))
                {
                    StreamResourceInfo sr = Application.GetResourceStream(new Uri(fileName, UriKind.Relative));
                    using (BinaryReader br = new BinaryReader(sr.Stream))
                    {
                        byte[] data = br.ReadBytes((int)sr.Stream.Length);
                        SaveToIsoStore(fileName, data);
                    }
                }
            }
        }

        private static void SaveToIsoStore(string fileName, byte[] data)
        {
            string strBaseDir = string.Empty;
            string delimStr = "/\\";
            char[] delimiter = delimStr.ToCharArray();
            string[] dirsPath = fileName.Split(delimiter);

            using (IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication())
            {
                //Recreate the directory structure
                for (int i = 0; i < dirsPath.Length - 1; i++)
                {
                    strBaseDir = System.IO.Path.Combine(strBaseDir, dirsPath[i]);
                    isoStore.CreateDirectory(strBaseDir);
                }

                //Remove existing file
                if (isoStore.FileExists(fileName))
                {
                    isoStore.DeleteFile(fileName);
                }

                //Write the file
                using (BinaryWriter bw = new BinaryWriter(isoStore.CreateFile(fileName)))
                {
                    bw.Write(data);
                    bw.Close();
                }
            }
        }

        public static void NavigateToHtmlFile(this WebBrowser webBrowser, string fileName)
        {
            SaveFileToIsoStore(fileName);
            using (IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (isoStore.FileExists(fileName))
                {
                    webBrowser.Navigate(new Uri(fileName, UriKind.Relative));
                }
                else
                {
                    //something bad has happened here
                }
            }
        }
    }
}
